summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMiloslav Trmač <mitr@redhat.com>2018-07-28 08:45:11 +0200
committerAtomic Bot <atomic-devel@projectatomic.io>2018-08-01 18:22:59 +0000
commit3d1449b2cccdf6c84248c82758b0850c971d05be (patch)
treef9fd3a5d710582f2b947f849a25a03ad8e68c86f
parent1c2d245c47cf087471556cdde77b8265c4386b93 (diff)
downloadpodman-3d1449b2cccdf6c84248c82758b0850c971d05be.tar.gz
podman-3d1449b2cccdf6c84248c82758b0850c971d05be.tar.bz2
podman-3d1449b2cccdf6c84248c82758b0850c971d05be.zip
RFC: Rename runtime.pullImage to runtime.pullImageFromHeuristicSource
This is similar to the PushImageToHeuristicDestination RFC. The goal is to be very explicit about which functions try to heuristically guess what is the expected format of the string. Not quite "shaming" the users, but making sure they stand out. RFC: - Is this at all acceptable? Desirable? Should not change behavior (but does not add unit tests). Signed-off-by: Miloslav Trmač <mitr@redhat.com> Closes: #1176 Approved by: rhatdan
-rw-r--r--libpod/image/image.go2
-rw-r--r--libpod/image/pull.go4
2 files changed, 3 insertions, 3 deletions
diff --git a/libpod/image/image.go b/libpod/image/image.go
index 56fe58e7f..9447ec9e1 100644
--- a/libpod/image/image.go
+++ b/libpod/image/image.go
@@ -145,7 +145,7 @@ func (ir *Runtime) New(ctx context.Context, name, signaturePolicyPath, authfile
if signaturePolicyPath == "" {
signaturePolicyPath = ir.SignaturePolicyPath
}
- imageName, err := ir.pullImage(ctx, name, writer, authfile, signaturePolicyPath, signingoptions, dockeroptions, forceSecure)
+ imageName, err := ir.pullImageFromHeuristicSource(ctx, name, writer, authfile, signaturePolicyPath, signingoptions, dockeroptions, forceSecure)
if err != nil {
return nil, errors.Wrapf(err, "unable to pull %s", name)
}
diff --git a/libpod/image/pull.go b/libpod/image/pull.go
index 1a77d89c8..f3a10d94d 100644
--- a/libpod/image/pull.go
+++ b/libpod/image/pull.go
@@ -200,9 +200,9 @@ func (ir *Runtime) pullGoalFromImageReference(ctx context.Context, srcRef types.
return ir.pullGoalFromGoalNames(goalNames)
}
// pullImage pulls an image based on input name, which may involve from configured registries.
// Use pullImageFromReference if the source is known precisely.
-func (ir *Runtime) pullImage(ctx context.Context, inputName string, writer io.Writer, authfile, signaturePolicyPath string, signingOptions SigningOptions, dockerOptions *DockerRegistryOptions, forceSecure bool) ([]string, error) {
+func (ir *Runtime) pullImageFromHeuristicSource(ctx context.Context, inputName string, writer io.Writer, authfile, signaturePolicyPath string, signingOptions SigningOptions, dockerOptions *DockerRegistryOptions, forceSecure bool) ([]string, error) {
var goal pullGoal
sc := GetSystemContext(signaturePolicyPath, authfile, false)
srcRef, err := alltransports.ParseImageName(inputName)
@@ -200,9 +200,9 @@ func (ir *Runtime) pullGoalFromImageReference(ctx context.Context, srcRef types.
return ir.pullGoalFromGoalNames(goalNames)
}
-// pullImage pulls an image based on input name, which may involve from configured registries.
+// pullImageFromHeuristicSource pulls an image based on inputName, which is heuristically parsed and may involve configured registries.
// Use pullImageFromReference if the source is known precisely.